from setuptools import setup

setup(name='th_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['th_distributions'],
      author='Travis Helm',
      author_email='travhao@gmail.com',
      zip_safe=False)
